a_pdf_scraper_2: A pdf scraper function v2

Description Usage Details

View source: R/apdf_scraper2.R

Description

Pdf to csv converter This function allows you to scrap one or more pdfs with one or several pages. The scraping method results into a .csv file per each pdf processed. To do so, please follow the following example.

Usage

1
a_pdf_scraper_2(pdf_location, csv_location)

Details

Copy step 1 and 2 and replace with your folder locations. Copy step 3 and press ctrl+enter Example:

# Step 1. pdf_location <-"C:/the name of the folder where is my PDF/"

# Step 2. csv_location <-"C:/the name of the folder where is my PDF/"

# Step 3. a_pdf_scraper(pdf_location, csv_location)

Finally, check the .csv folder to see the pdf converted.


LucyBejarano/apdfscraper2 documentation built on Dec. 17, 2021, 1:15 a.m.